import os
import asyncio
import traceback

from funciones.mainselenium import verificar_mensajes, monitorear_ventana, enviar_mensaje
from funciones.utiles import borrar_emojis
from adaptadores.atapis import enviar_mensaje_del_usuario, obtener_mensajes_del_cliente
from bd.bd import *


async def monitorear_mensajes(conexion, driver):
    # print("[[ Monitoreando mensajes ]]")
    rta = verificar_mensajes(driver)

    if rta['Dato']:
        mensajes = rta['Dato']

        await insertar(conexion, 'usuarios', (mensajes[0][1], mensajes[0][2]))

        await insertar(conexion, 'mensajes', *mensajes)


async def monitorear_chat(conexion, driver):
    # print("[[ Monitoreando ventana]]")
    rta = monitorear_ventana(driver)

    if rta['Estado'] is False or rta['Dato'] is None:
        return

    id_ultimo_mensaje_navegador = rta['Dato']['id_mensaje']

    ultimo_mensaje = await obtener_id_ultimo_mensaje(conexion, rta['Dato']['telefono'])

    if len(ultimo_mensaje) > 0:
        id_ultimo_mensaje = ultimo_mensaje[-1]['id_mensaje']

        if id_ultimo_mensaje_navegador == id_ultimo_mensaje:
            return

        else:
            rta['Dato']['estado'] = 'pendiente'
            await insertar(conexion, 'mensajes', *rta['Dato'].values())


async def enviar_pendientes_a_usuarios(conexion, driver):
    # print("[[ Enviando pendientes ]]")

    # Obtenemos todos los mensajes pendientes para enviar a usuarios
    mensajes = await obtener_mensajes_a_enviar(conexion)

    for mensaje in mensajes:

        # Seteamos el mensaje para definir que ya esta siendo enviado
        await actualizar_mensaje_fila(conexion, mensaje['rowid'], 'enviando')

        # Buscamos el nombre agendado del usuario
        usuario = await obtener_usuario(conexion, mensaje['telefono'])

        nombre_agendado = usuario['nombre_agendado']

        await enviar_mensaje(driver, mensaje['mensaje'], mensaje['telefono'], nombre_agendado)

        await actualizar_mensaje_fila(conexion, mensaje['rowid'], 'enviado')


async def obtener_pendientes_y_enviar(conexion, host):
    # print("[[ Obteniendo pendientes ]]")

    pendientes = await obtener_pendientes(conexion)

    for pendiente in pendientes:

        rta = await enviar_mensaje_del_usuario(telefono_origen=pendiente['telefono'],
                                               telefono_destino=os.getenv('TELEFONO'),
                                               mensaje=pendiente['mensaje'],
                                               nombre=pendiente['nombre_agendado'],
                                               hora_mensaje=pendiente['fecha_hora'],
                                               clase=pendiente['clase'],
                                               host=host)

        if rta['Estado']:
            await actualizar_estado_mensaje(conexion, pendiente['id_mensaje'], 'enviado')


async def obtener_mensajes_para_enviar(conexion):
    # print("[[ Obteniendo para enviar]]")

    rta_pendientes = obtener_mensajes_del_cliente(os.getenv("TELEFONO"), os.getenv("IP_ATAPIS"))

    if rta_pendientes['Estado']:

        pendientes = rta_pendientes['Dato']

        for pendiente in pendientes:
            await insertar(conexion, 'fila', *(pendiente["telefono_destino"],
                                               pendiente["mensaje"],
                                               'pendiente',
                                               pendiente['telefono_destino'],
                                               pendiente['fecha_hora']))
