import asyncio
import logging
import sys
import os
import argparse
import traceback
import selenium.common.exceptions as seleniumexc

if sys.platform == 'linux':
    sys.path.append(os.getcwd() + "/funciones")
else:
    sys.path.append(os.getcwd() + "\\funciones")

from bd.bd import bootstrap_bd
from funciones.asincrono import *
from funciones.principales import *

logging.basicConfig(filename="atlog.log", level=logging.ERROR)

# Al ejecutar el servicio se le deben pasar los siguientes parámetros
parser = argparse.ArgumentParser(description='atwsp')

parser.add_argument(
    '-telefono',
    help='El telefono correspondiente al que esta en atapis',
    required=True
)

parser.add_argument(
    '-perfil',
    help='La ruta donde se encuentra el perfil de Firefox para correr Selenium',
    required=True
)

parser.add_argument(
    '-gecko',
    help='El telefono correspondiente al que esta en atapis',
    required=True
)

parser.add_argument(
    '-atapis',
    help='El telefono correspondiente al que esta en atapis',
    required=True
)

# Guardo los parámetros recibidos
args = []
args.extend(sys.argv)
args.pop(0)
args = parser.parse_args(args)

# Creamos las variables de entorno
if args.telefono is not None:
    os.environ['TELEFONO'] = args.telefono

if args.perfil is not None:
    os.environ['RUTA_PERFIL'] = args.perfil

if args.gecko is not None:
    os.environ['RUTA_GECKO'] = args.gecko

if args.atapis is not None:
    os.environ['IP_ATAPIS'] = f"http://{args.atapis}:901"


async def main():
    # Inicializamos la base de datos, creando las tablas si no existen
    conexion = await bootstrap_bd()

    conexion.row_factory = aiosqlite.Row

    # Conectamos con el driver de selenium
    driver = abrir_navegador()

    ip_atapis = os.getenv("IP_ATAPIS")

    # Este loop es el que ejecuta constantemente las corutinas.
    # El orden que siguen influye en el comportamiento a la hora de responder o leer mensajes.
    # Por ejemplo, si la corutina monitorear_chat es movida ultima en el loop, es probable que
    # queden colgados algunos chats sin que el bot les responda, ya que otra corutina (por ejemplo monitorear_mensajes)
    # que mueva la pantalla hacia otro chat o parte de la web de WhatsApp va a interferir a la hora de monitorear la
    # ventana. Es por eso que es recomendable dejar la corutina monitorear_chat al principio del while, ya que de esta
    # manera, antes de ejecutar cualquiera de las otras corutinas nos aseguramos de leer primero
    # los mensajes que vayan saliendo en la pantalla de un chat.

    while True:
        try:

            await monitorear_chat(conexion, driver)

            await obtener_mensajes_para_enviar(conexion)

            await monitorear_chat(conexion, driver)

            await obtener_pendientes_y_enviar(conexion, ip_atapis)

            await monitorear_chat(conexion, driver)

            await enviar_pendientes_a_usuarios(conexion, driver)

            await monitorear_chat(conexion, driver)

            await monitorear_mensajes(conexion, driver)

        except seleniumexc.StaleElementReferenceException:
            print(f"Tocando pantalla {datetime.now()}")
            continue

        except Exception:
            print(traceback.format_exc())


asyncio.run(main())
